@@ -3,16 +3,16 @@
  * Copyright 2008 The gstreamermm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -62,7 +62,7 @@ void init()
   if(!s_init)
   {
     Glib::init();
-    gst_init(NULL, NULL);
+    gst_init(0, 0);
     initialize_wrap_system();
 
     s_init = true;
@@ -114,7 +114,7 @@ bool init_check(std::auto_ptr<Glib::Error>& error)
     Glib::init();
 
     GError* gerror = 0;
-    result = gst_init_check(NULL, NULL, &gerror);
+    result = gst_init_check(0, 0, &gerror);
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
     if(gerror)
